gene_types: genes EMR are interested in

View source: R/gene_types.R

gene_typesR Documentation

genes EMR are interested in

Description

genes EMR are interested in

Usage

gene_types(genes, types = NULL)

Arguments

genes

A list of gene names

types

A data frame of annotation types with columns for: the annotation name, the contains a character vector for grep command and general info about the gene. If NULL immune_genes are used


KatrionaGoldmann/geneAnnotations documentation built on June 19, 2022, 4:54 p.m.