| gene_types | R Documentation |
genes EMR are interested in
gene_types(genes, types = NULL)
genes |
A list of gene names |
types |
A data frame of annotation types with columns for: the annotation name, the contains a character vector for grep command and general info about the gene. If NULL immune_genes are used |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.